@@ -17,17 +17,18 @@ class TestDataReads(TestCase):
     def setUp(self):
         self.pr = cProfile.Profile()
         self.pr.enable()
-        print("\n<<<---")
+        # print("\n<<<---")
         self.clientArgs = helpers.get_db_client_kwargs()
 
     def tearDown(self):
-        p = Stats(self.pr)
-        p.strip_dirs()
-        p.sort_stats('cumtime')
-        p.print_stats(20)
-        print("\n--->>")
+        # p = Stats(self.pr)
+        # p.strip_dirs()
+        # p.sort_stats('cumtime')
+        # p.print_stats(20)
+        # print("\n--->>")
+        pass
 
-    def check_df_format(self, df):
+    def check_standard_df_format(self, df):
         idx = ['device_id', 'device_metric_type_id', 'measurement_date']
         # The DataFrame should have a MultiIndex
         self.assertIsInstance(df.index, pd.MultiIndex)
@@ -39,7 +40,9 @@ class TestDataReads(TestCase):
         self.assertTrue(ptypes.is_string_dtype(df.index.get_level_values(1)))
         # The device_id index column should be a int64
         self.assertTrue(
-            ptypes.is_datetime64tz_dtype(df.index.get_level_values(2)))
+            ptypes.is_datetime64_ns_dtype(df.index.get_level_values(2)))
+        # Check that the dataframe is not empty
+        self.assertFalse(df.empty)
 
     def test_latest_metrics(self):
         device_ids = [353, 398, 399]
@@ -48,14 +51,12 @@ class TestDataReads(TestCase):
         c2 = TimescaleClientJSON('device_metrics_json',
                                  **helpers.get_db_client_kwargs())
         df2 = c2.get_latest_metrics(device_ids, device_metrics, 5)
-        print(df2)
-        self.check_df_format(df2)
+        self.check_standard_df_format(df2)
 
         c1 = TimescaleClientNarrow('device_metrics',
                                    **helpers.get_db_client_kwargs())
         df1 = c1.get_latest_metrics(device_ids, device_metrics, 5)
-        print(df1)
-        self.check_df_format(df1)
+        self.check_standard_df_format(df2)
 
     def test_df_narrow_format(self):
         # Sample Narrow Format result DF
@@ -96,7 +97,7 @@ class TestDataReads(TestCase):
                                '2019-09-19 00:00:00.000000+00:00',
                                '2019-09-19 00:01:00.000000+00:00']})
         df = c.standardize_df(query_result_df)
-        self.check_df_format(df)
+        self.check_standard_df_format(df)
 
         # Accessing Device Metric Timeseries (Sorted in ascending order)
         self.assertEqual([0, 1100000, -1100000],
@@ -125,7 +126,7 @@ class TestDataReads(TestCase):
                          {"P": 300, "Q": -200.1},
                          {"P": 978097, "Q": -30.12}]})
         df = c.standardize_df(query_result_df, ['P_Supply', 'P'])
-        self.check_df_format(df)
+        self.check_standard_df_format(df)
 
         # Accessing Device Metric Timeseries
         self.assertEqual([0, 1100000, -1100000],
